diff --git a/modules/addons/awit_cozaepp/lang/english.php b/modules/addons/awit_zacr/lang/english.php
similarity index 75%
rename from modules/addons/awit_cozaepp/lang/english.php
rename to modules/addons/awit_zacr/lang/english.php
index 2723a4abb5282d174bda1d8e7cd63eb05bf31046..e2a1027f7d2a6d66a2927f78551045788a762f60 100644
--- a/modules/addons/awit_cozaepp/lang/english.php
+++ b/modules/addons/awit_zacr/lang/english.php
@@ -1,6 +1,6 @@
 <?php
 
-$_ADDONLANG['intro'] = "AWIT COZAEPP Module";
+$_ADDONLANG['intro'] = "AWIT ZACR Module";
 $_ADDONLANG['description'] = "This module is to facilitate displaying of epp messages.";
 $_ADDONLANG['documentation'] = "Pending..";
 
diff --git a/modules/registrars/cozaepp/Net/EPP/COPYING b/modules/registrars/zacr/Net/EPP/COPYING
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/COPYING
rename to modules/registrars/zacr/Net/EPP/COPYING
diff --git a/modules/registrars/cozaepp/Net/EPP/Client.php b/modules/registrars/zacr/Net/EPP/Client.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Client.php
rename to modules/registrars/zacr/Net/EPP/Client.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame.php b/modules/registrars/zacr/Net/EPP/Frame.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame.php
rename to modules/registrars/zacr/Net/EPP/Frame.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command.php b/modules/registrars/zacr/Net/EPP/Frame/Command.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Check.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Check.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Check.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Check.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Check/Domain.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Check/Domain.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Check/Domain.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Check/Domain.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Check/Host.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Check/Host.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Check/Host.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Check/Host.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Create.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Create.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Create.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Create.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Create/Contact.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Create/Contact.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Create/Contact.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Create/Contact.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Create/Domain.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Create/Domain.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Create/Domain.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Create/Domain.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Create/Host.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Create/Host.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Create/Host.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Create/Host.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Info.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Info.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Info.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Info.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Info/Contact.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Info/Contact.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Info/Contact.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Info/Contact.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Info/Domain.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Info/Domain.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Info/Domain.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Info/Domain.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Info/Host.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Info/Host.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Info/Host.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Info/Host.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Login.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Login.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Login.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Login.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Renew.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Renew.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Renew.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Renew.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Renew/Domain.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Renew/Domain.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Renew/Domain.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Renew/Domain.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Transfer.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Transfer.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Transfer.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Transfer.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Transfer/Contact.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Transfer/Contact.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Transfer/Contact.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Transfer/Contact.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Transfer/Domain.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Transfer/Domain.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Transfer/Domain.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Transfer/Domain.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Update.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Update.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Update.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Update.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Command/Update/Domain.php b/modules/registrars/zacr/Net/EPP/Frame/Command/Update/Domain.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Command/Update/Domain.php
rename to modules/registrars/zacr/Net/EPP/Frame/Command/Update/Domain.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Greeting.php b/modules/registrars/zacr/Net/EPP/Frame/Greeting.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Greeting.php
rename to modules/registrars/zacr/Net/EPP/Frame/Greeting.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Hello.php b/modules/registrars/zacr/Net/EPP/Frame/Hello.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Hello.php
rename to modules/registrars/zacr/Net/EPP/Frame/Hello.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Frame/Response.php b/modules/registrars/zacr/Net/EPP/Frame/Response.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Frame/Response.php
rename to modules/registrars/zacr/Net/EPP/Frame/Response.php
diff --git a/modules/registrars/cozaepp/Net/EPP/ObjectSpec.php b/modules/registrars/zacr/Net/EPP/ObjectSpec.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/ObjectSpec.php
rename to modules/registrars/zacr/Net/EPP/ObjectSpec.php
diff --git a/modules/registrars/cozaepp/Net/EPP/Protocol.php b/modules/registrars/zacr/Net/EPP/Protocol.php
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/Protocol.php
rename to modules/registrars/zacr/Net/EPP/Protocol.php
diff --git a/modules/registrars/cozaepp/Net/EPP/README b/modules/registrars/zacr/Net/EPP/README
similarity index 100%
rename from modules/registrars/cozaepp/Net/EPP/README
rename to modules/registrars/zacr/Net/EPP/README
diff --git a/modules/registrars/cozaepp/logo.gif b/modules/registrars/zacr/logo.gif
similarity index 100%
rename from modules/registrars/cozaepp/logo.gif
rename to modules/registrars/zacr/logo.gif
diff --git a/modules/registrars/cozaepp/cozaepp.php b/modules/registrars/zacr/zacrepp.php
similarity index 93%
rename from modules/registrars/cozaepp/cozaepp.php
rename to modules/registrars/zacr/zacrepp.php
index 507b55f273bea8f7007d3266d918c1da6c4c002b..bbb137cb309fdb2f8b2db965f60f658a2351bc3e 100644
--- a/modules/registrars/cozaepp/cozaepp.php
+++ b/modules/registrars/zacr/zacrepp.php
@@ -40,7 +40,7 @@ if (!defined("WHMCS"))
 	die("This file cannot be accessed directly");
 
 # Configuration array
-function cozaepp_getConfigArray() {
+function zacr_getConfigArray() {
 	$configarray = array(
 		"Username" => array( "Type" => "text", "Size" => "20", "Description" => "Enter your username here" ),
 		"Password" => array( "Type" => "password", "Size" => "20", "Description" => "Enter your password here" ),
@@ -50,7 +50,7 @@ function cozaepp_getConfigArray() {
 	return $configarray;
 }
 
-function cozaepp_AdminCustomButtonArray() {
+function zacr_AdminCustomButtonArray() {
 	$buttonarray = array(
 		"Approve Transfer" => "ApproveTransfer",
 		"Cancel Transfer Request" => "CancelTransferRequest",
@@ -61,7 +61,7 @@ function cozaepp_AdminCustomButtonArray() {
 }
 
 # Function to return current nameservers
-function cozaepp_GetNameservers($params) {
+function zacr_GetNameservers($params) {
 	# Grab variables
 	$sld = $params["sld"];
 	$tld = $params["tld"];
@@ -70,7 +70,7 @@ function cozaepp_GetNameservers($params) {
 
 	# Get client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Get list of nameservers for domain
 		$result = $client->request($xml = '
@@ -89,7 +89,7 @@ function cozaepp_GetNameservers($params) {
 		# Parse XML result
 		$doc = new DOMDocument();
 		$doc->loadXML($result);
-		logModuleCall('Cozaepp', 'GetNameservers', $xml, $result);
+		logModuleCall('ZACR', 'GetNameservers', $xml, $result);
 
 		# Pull off status
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
@@ -123,7 +123,7 @@ function cozaepp_GetNameservers($params) {
 
 
 # Function to save set of nameservers
-function cozaepp_SaveNameservers($params) {
+function zacr_SaveNameservers($params) {
 	# Grab variables
 	$sld = $params["sld"];
 	$tld = $params["tld"];
@@ -166,7 +166,7 @@ function cozaepp_SaveNameservers($params) {
 
 	# Get client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Grab list of current nameservers
 		$request = $client->request( $xml = '
@@ -184,7 +184,7 @@ function cozaepp_SaveNameservers($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'SaveNameservers', $xml, $request);
+		logModuleCall('ZACR', 'SaveNameservers', $xml, $request);
 
 		# Pull off status
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
@@ -235,7 +235,7 @@ function cozaepp_SaveNameservers($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'SaveNameservers', $xml, $request);
+		logModuleCall('ZACR', 'SaveNameservers', $xml, $request);
 
 		# Pull off status
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
@@ -259,7 +259,7 @@ function cozaepp_SaveNameservers($params) {
 
 
 # NOT IMPLEMENTED
-function cozaepp_GetRegistrarLock($params) {
+function zacr_GetRegistrarLock($params) {
 	# Grab variables
 	$sld = $params["sld"];
 	$tld = $params["tld"];
@@ -276,20 +276,20 @@ function cozaepp_GetRegistrarLock($params) {
 }
 
 # NOT IMPLEMENTED
-function cozaepp_SaveRegistrarLock($params) {
+function zacr_SaveRegistrarLock($params) {
 	$values["error"] = "SaveRegistrarLock: Current co.za policy does not allow for the addition of client-side statuses on domains.";
 	return $values;
 }
 
 # Function to retrieve an available contact id
-function _cozaepp_CheckContact($prehash) {
+function _zacr_CheckContact($prehash) {
 	$domain  = $prehash;
 	$prehash = $prehash . time() . rand(0, 1000000);
 	$contactid = substr(md5($prehash), 0,15);
 
 	# Get client instance and check for available contact id
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		$contactAvailable = 0;
 		$count = 0;
@@ -312,7 +312,7 @@ function _cozaepp_CheckContact($prehash) {
 			# Parse XML result
 			$doc= new DOMDocument();
 			$doc->loadXML($request);
-			logModuleCall('Cozaepp', 'RegisterDomain:CheckContact', $xml, $request);
+			logModuleCall('ZACR', 'RegisterDomain:CheckContact', $xml, $request);
 
 			# Pull off status
 			$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
@@ -353,7 +353,7 @@ function _cozaepp_CheckContact($prehash) {
 }
 
 # Function to register domain
-function cozaepp_RegisterDomain($params) {
+function zacr_RegisterDomain($params) {
 	# Grab varaibles
 	$sld = $params["sld"];
 	$tld = $params["tld"];
@@ -428,7 +428,7 @@ function cozaepp_RegisterDomain($params) {
 
 	# Get client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Send registration
 		$request = $client->request($xml = '
@@ -464,7 +464,7 @@ function cozaepp_RegisterDomain($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'RegisterDomain', $xml, $request);
+		logModuleCall('ZACR', 'RegisterDomain', $xml, $request);
 
 		# Pull off status
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
@@ -493,7 +493,7 @@ function cozaepp_RegisterDomain($params) {
 
 		# Some SLDs require the presence of admin, billing and tech contacts.
 		# Check if our domain has the requirement and get/create the required contact id.
-		$_server = _cozaepp_SldLookup($domain);
+		$_server = _zacr_SldLookup($domain);
 
 		if ($_server['additional_contacts'])  {
 			$request = $client->request($xml = '
@@ -529,7 +529,7 @@ function cozaepp_RegisterDomain($params) {
 			# Parse XML result
 			$doc= new DOMDocument();
 			$doc->loadXML($request);
-			logModuleCall('Cozaepp', 'RegisterDomain', $xml, $request);
+			logModuleCall('ZACR', 'RegisterDomain', $xml, $request);
 
 			# Pull off status
 			$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
@@ -567,7 +567,7 @@ function cozaepp_RegisterDomain($params) {
 		$request = $client->request($domaincreate);
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'RegisterDomain', $domaincreate, $request);
+		logModuleCall('ZACR', 'RegisterDomain', $domaincreate, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -588,7 +588,7 @@ function cozaepp_RegisterDomain($params) {
 
 
 # Function to transfer a domain
-function cozaepp_TransferDomain($params) {
+function zacr_TransferDomain($params) {
 	# Grab variables
 	$testmode = $params["TestMode"];
 	$sld = $params["sld"];
@@ -627,7 +627,7 @@ function cozaepp_TransferDomain($params) {
 
 	# Get client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Initiate transfer
 		$request = $client->request($xml = '
@@ -645,7 +645,7 @@ function cozaepp_TransferDomain($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'TransferDomain', $xml, $request);
+		logModuleCall('ZACR', 'TransferDomain', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -690,7 +690,7 @@ function cozaepp_TransferDomain($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'TransferDomain', $xml, $request);
+		logModuleCall('ZACR', 'TransferDomain', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -716,7 +716,7 @@ function cozaepp_TransferDomain($params) {
 
 
 # Function to renew domain
-function cozaepp_RenewDomain($params) {
+function zacr_RenewDomain($params) {
 	# Grab variables
 	$sld = $params["sld"];
 	$tld = $params["tld"];
@@ -726,7 +726,7 @@ function cozaepp_RenewDomain($params) {
 
 	# Get client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Send renewal request
 		$request = $client->request($xml = '
@@ -745,7 +745,7 @@ function cozaepp_RenewDomain($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'RenewDomain', $xml, $request);
+		logModuleCall('ZACR', 'RenewDomain', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -780,7 +780,7 @@ function cozaepp_RenewDomain($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'RenewDomain', $xml, $request);
+		logModuleCall('ZACR', 'RenewDomain', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -804,7 +804,7 @@ function _getContactDetails($domain, $client = null) {
 	# Get client instance
 	try {
 		if (!isset($client)) {
-			$client = _cozaepp_Client($domain);
+			$client = _zacr_Client($domain);
 		}
 
 		# Grab domain info
@@ -824,7 +824,7 @@ function _getContactDetails($domain, $client = null) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', '_GetContactDetails', $xml, $request);
+		logModuleCall('ZACR', '_GetContactDetails', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -857,7 +857,7 @@ function _getContactDetails($domain, $client = null) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', '_GetContactDetails', $xml, $request);
+		logModuleCall('ZACR', '_GetContactDetails', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -893,7 +893,7 @@ function _getContactDetails($domain, $client = null) {
 }
 
 # Function to grab contact details
-function cozaepp_GetContactDetails($params) {
+function zacr_GetContactDetails($params) {
 	# Grab variables
 	$sld = $params["sld"];
 	$tld = $params["tld"];
@@ -1003,7 +1003,7 @@ function _getContactDetailsFromParams($params) {
 }
 
 # Function to save contact details
-function cozaepp_SaveContactDetails($params) {
+function zacr_SaveContactDetails($params) {
 	# Grab variables
 	$tld = $params["tld"];
 	$sld = $params["sld"];
@@ -1026,7 +1026,7 @@ function cozaepp_SaveContactDetails($params) {
 
 	# Get client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Grab domain info
 		$request = $client->request($xml = '
@@ -1044,7 +1044,7 @@ function cozaepp_SaveContactDetails($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'SaveContactDetails', $xml, $request);
+		logModuleCall('ZACR', 'SaveContactDetails', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -1091,7 +1091,7 @@ function cozaepp_SaveContactDetails($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'SaveContactDetails', $xml, $request);
+		logModuleCall('ZACR', 'SaveContactDetails', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -1113,7 +1113,7 @@ function cozaepp_SaveContactDetails($params) {
 
 
 # NOT IMPLEMENTED
-function cozaepp_GetEPPCode($params) {
+function zacr_GetEPPCode($params) {
 	# Grab variables
 	$username = $params["Username"];
 	$password = $params["Password"];
@@ -1132,7 +1132,7 @@ function cozaepp_GetEPPCode($params) {
 
 
 # Function to register nameserver
-function cozaepp_RegisterNameserver($params) {
+function zacr_RegisterNameserver($params) {
 	# Grab varaibles
 	$username = $params["Username"];
 	$password = $params["Password"];
@@ -1146,7 +1146,7 @@ function cozaepp_RegisterNameserver($params) {
 
 	# Grab client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Register nameserver
 		$request = $client->request($xml = '
@@ -1171,7 +1171,7 @@ function cozaepp_RegisterNameserver($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'RegisterNameserver', $xml, $request);
+		logModuleCall('ZACR', 'RegisterNameserver', $xml, $request);
 
 		# Pull off status
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
@@ -1196,7 +1196,7 @@ function cozaepp_RegisterNameserver($params) {
 
 
 # Modify nameserver
-function cozaepp_ModifyNameserver($params) {
+function zacr_ModifyNameserver($params) {
 	# Grab variables
 	$username = $params["Username"];
 	$password = $params["Password"];
@@ -1211,7 +1211,7 @@ function cozaepp_ModifyNameserver($params) {
 
 	# Grab client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Modify nameserver
 		$request = $client->request($xml = '
@@ -1236,7 +1236,7 @@ function cozaepp_ModifyNameserver($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'ModifyNameserver', $xml, $request);
+		logModuleCall('ZACR', 'ModifyNameserver', $xml, $request);
 
 		# Pull off status
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
@@ -1259,7 +1259,7 @@ function cozaepp_ModifyNameserver($params) {
 
 
 # Delete nameserver
-function cozaepp_DeleteNameserver($params) {
+function zacr_DeleteNameserver($params) {
 	# Grab variables
 	$username = $params["Username"];
 	$password = $params["Password"];
@@ -1272,7 +1272,7 @@ function cozaepp_DeleteNameserver($params) {
 
 	# Grab client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# If we were given hostname. blow away all of the stuff behind it and allow us to remove hostname
 		$nameserver = preg_replace('/\.\.\S+/','',$nameserver);
@@ -1299,7 +1299,7 @@ function cozaepp_DeleteNameserver($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'DeleteNameserver', $xml, $request);
+		logModuleCall('ZACR', 'DeleteNameserver', $xml, $request);
 
 		# Pull off status
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
@@ -1322,7 +1322,7 @@ function cozaepp_DeleteNameserver($params) {
 
 
 # Function to return meaningful message from response code
-function _cozaepp_message($code) {
+function _zacr_message($code) {
 
 	return "Code $code";
 
@@ -1330,7 +1330,7 @@ function _cozaepp_message($code) {
 
 
 # Ack a POLL message
-function _cozaepp_ackpoll($client,$msgid) {
+function _zacr_ackpoll($client,$msgid) {
 	# Ack poll message
 	$request = $client->request($xml = '
 <epp xmlns="urn:ietf:params:xml:ns:epp-1.0">
@@ -1343,7 +1343,7 @@ function _cozaepp_ackpoll($client,$msgid) {
 	# Decipher XML
 	$doc = new DOMDocument();
 	$doc->loadXML($request);
-	logModuleCall('Cozaepp', 'ackpoll', $xml, $request);
+	logModuleCall('ZACR', 'ackpoll', $xml, $request);
 
 	$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 	$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -1356,7 +1356,7 @@ function _cozaepp_ackpoll($client,$msgid) {
 
 # Helper function to centrally provide data and information
 # about different SLDs.
-function _cozaepp_SldLookup($domain) {
+function _zacr_SldLookup($domain) {
 	# TLD server data provided by ZACR
 	$tldservers = array(
 		'co.za' => array(
@@ -1395,20 +1395,20 @@ function _cozaepp_SldLookup($domain) {
 	}
 }
 
-# Function to create internal COZA EPP request
-function _cozaepp_Client($domain=null) {
+# Function to create internal ZACR EPP request
+function _zacr_Client($domain=null) {
 	# Setup include dir
-	$include_path = ROOTDIR . '/modules/registrars/cozaepp';
+	$include_path = ROOTDIR . '/modules/registrars/zacr';
 	set_include_path($include_path . PATH_SEPARATOR . get_include_path());
 	# Include EPP stuff we need
 	require_once 'Net/EPP/Client.php';
 	require_once 'Net/EPP/Protocol.php';
 
 	# Grab module parameters
-	$params = getregistrarconfigoptions('cozaepp');
+	$params = getregistrarconfigoptions('zacr');
 
 	# Set server address and port based on parsed domain name
-	$_server = _cozaepp_SldLookup($domain);
+	$_server = _zacr_SldLookup($domain);
 
 	# Check if module parameters are sane
 	if (empty($params['Username']) || empty($params['Password'])) {
@@ -1456,12 +1456,12 @@ function _cozaepp_Client($domain=null) {
 	</command>
 </epp>
 ');
-	logModuleCall('Cozaepp', 'Connect', $xml, $request);
+	logModuleCall('ZACR', 'Connect', $xml, $request);
 
 	return $client;
 }
 
-function cozaepp_TransferSync($params) {
+function zacr_TransferSync($params) {
 	$domainid = $params['domainid'];
 	$domain = $params['domain'];
 	$sld = $params['sld'];
@@ -1478,7 +1478,7 @@ function cozaepp_TransferSync($params) {
 
 	# Grab domain info
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 		# Grab domain info
 		$request = $client->request($xml = '
 <epp:epp xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:epp="urn:ietf:params:xml:ns:epp-1.0"
@@ -1495,7 +1495,7 @@ function cozaepp_TransferSync($params) {
 
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'TransferSync', $xml, $request);
+		logModuleCall('ZACR', 'TransferSync', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -1504,7 +1504,7 @@ function cozaepp_TransferSync($params) {
 			$values['error'] = "TransferSync/domain-info($domain): Domain not found";
 			return $values;
 		} else if ($coderes != '1000') {
-			$values['error'] = "TransferSync/domain-info($domain): Code("._cozaepp_message($coderes).") $msg";
+			$values['error'] = "TransferSync/domain-info($domain): Code("._zacr_message($coderes).") $msg";
 			return $values;
 		}
 
@@ -1538,7 +1538,7 @@ function cozaepp_TransferSync($params) {
 	return $values;
 }
 
-function cozaepp_RecreateContact($params) {
+function zacr_RecreateContact($params) {
 	# Grab variables
 	$tld = $params["tld"];
 	$sld = $params["sld"];
@@ -1546,7 +1546,7 @@ function cozaepp_RecreateContact($params) {
 
 	# Get client instance
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Fetching contact details
 		$contact = _getContactDetails($domain, $client);
@@ -1557,7 +1557,7 @@ function cozaepp_RecreateContact($params) {
 		}
 
 		# Check for available contact id
-		$registrant = _cozaepp_CheckContact($domain);
+		$registrant = _zacr_CheckContact($domain);
 
 		# Recreate contact
 		$request = $client->request($xml = '
@@ -1594,7 +1594,7 @@ function cozaepp_RecreateContact($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'RecreateContact', $xml, $request);
+		logModuleCall('ZACR', 'RecreateContact', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -1623,7 +1623,7 @@ function cozaepp_RecreateContact($params) {
 		# Parse XML result
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'RecreateContact', $xml, $request);
+		logModuleCall('ZACR', 'RecreateContact', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
@@ -1642,7 +1642,7 @@ function cozaepp_RecreateContact($params) {
 	return $values;
 }
 
-function cozaepp_Sync($params) {
+function zacr_Sync($params) {
 	$domainid = $params['domainid'];
 	$domain = $params['domain'];
 	$sld = $params['sld'];
@@ -1659,7 +1659,7 @@ function cozaepp_Sync($params) {
 
 	# Grab domain info
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 		# Grab domain info
 		$request = $client->request($xml = '
 <epp:epp xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:epp="urn:ietf:params:xml:ns:epp-1.0"
@@ -1676,7 +1676,7 @@ function cozaepp_Sync($params) {
 
 		$doc= new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'Sync', $xml, $request);
+		logModuleCall('ZACR', 'Sync', $xml, $request);
 
 		# Initialize the owningRegistrar which will contain the owning registrar
 		# The <domain:clID> element contains the unique identifier of the registrar that owns the domain.
@@ -1699,7 +1699,7 @@ function cozaepp_Sync($params) {
 				$owningRegistrar = $doc->getElementsByTagName('infData')->item(0)->getElementsByTagName('clID')->item(0)->nodeValue;
 			}
 		} else {
-			$values['error'] = "Sync/domain-info($domain): Code("._cozaepp_message($coderes).") $msg";
+			$values['error'] = "Sync/domain-info($domain): Code("._zacr_message($coderes).") $msg";
 			return $values;
 		}
 
@@ -1745,14 +1745,14 @@ function cozaepp_Sync($params) {
 }
 
 
-function cozaepp_RequestDelete($params) {
+function zacr_RequestDelete($params) {
 	$sld = $params['sld'];
 	$tld = $params['tld'];
 	$domain = strtolower("$sld.$tld");
 
 	# Grab domain info
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Grab domain info
 		$request = $client->request($xml = '
@@ -1771,14 +1771,14 @@ function cozaepp_RequestDelete($params) {
 		# Parse XML result
 		$doc = new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'RequestDelete', $xml, $request);
+		logModuleCall('ZACR', 'RequestDelete', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
 
 		# Check result
 		if($coderes != '1001') {
-			$values['error'] = 'RequestDelete/domain-info('.$domain.'): Code('._cozaepp_message($coderes).") $msg";
+			$values['error'] = 'RequestDelete/domain-info('.$domain.'): Code('._zacr_message($coderes).") $msg";
 			return $values;
 		}
 
@@ -1792,14 +1792,14 @@ function cozaepp_RequestDelete($params) {
 	return $values;
 }
 
-function cozaepp_ApproveTransfer($params) {
+function zacr_ApproveTransfer($params) {
 	$sld = $params['sld'];
 	$tld = $params['tld'];
 	$domain = strtolower("$sld.$tld");
 
 	# Grab domain info
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Grab domain info
 		$request = $client->request($xml = '
@@ -1817,14 +1817,14 @@ function cozaepp_ApproveTransfer($params) {
 		# Parse XML result
 		$doc = new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'ApproveTransfer', $xml, $request);
+		logModuleCall('ZACR', 'ApproveTransfer', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
 
 		# Check result
 		if($coderes != '1000') {
-			$values['error'] = 'ApproveTransfer/domain-info('.$domain.'): Code('._cozaepp_message($coderes).") $msg";
+			$values['error'] = 'ApproveTransfer/domain-info('.$domain.'): Code('._zacr_message($coderes).") $msg";
 			return $values;
 		}
 
@@ -1839,14 +1839,14 @@ function cozaepp_ApproveTransfer($params) {
 }
 
 
-function cozaepp_CancelTransferRequest($params) {
+function zacr_CancelTransferRequest($params) {
 	$sld = $params['sld'];
 	$tld = $params['tld'];
 	$domain = strtolower("$sld.$tld");
 
 	# Grab domain info
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Grab domain info
 		$request = $client->request($xml = '
@@ -1864,14 +1864,14 @@ function cozaepp_CancelTransferRequest($params) {
 		# Parse XML result
 		$doc = new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'CancelTransferRequest', $xml, $request);
+		logModuleCall('ZACR', 'CancelTransferRequest', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
 
 		# Check result
 		if($coderes != '1000') {
-			$values['error'] = 'CancelTransferRequest/domain-info('.$domain.'): Code('._cozaepp_message($coderes).") $msg";
+			$values['error'] = 'CancelTransferRequest/domain-info('.$domain.'): Code('._zacr_message($coderes).") $msg";
 			return $values;
 		}
 
@@ -1886,14 +1886,14 @@ function cozaepp_CancelTransferRequest($params) {
 }
 
 
-function cozaepp_RejectTransfer($params) {
+function zacr_RejectTransfer($params) {
 	$sld = $params['sld'];
 	$tld = $params['tld'];
 	$domain = strtolower("$sld.$tld");
 
 	# Grab domain info
 	try {
-		$client = _cozaepp_Client($domain);
+		$client = _zacr_Client($domain);
 
 		# Grab domain info
 		$request = $client->request($xml = '
@@ -1911,14 +1911,14 @@ function cozaepp_RejectTransfer($params) {
 		# Parse XML result
 		$doc = new DOMDocument();
 		$doc->loadXML($request);
-		logModuleCall('Cozaepp', 'RejectTransfer', $xml, $request);
+		logModuleCall('ZACR', 'RejectTransfer', $xml, $request);
 
 		$coderes = $doc->getElementsByTagName('result')->item(0)->getAttribute('code');
 		$msg = $doc->getElementsByTagName('msg')->item(0)->nodeValue;
 
 		# Check result
 		if($coderes != '1000') {
-			$values['error'] = 'RejectTransfer/domain-info('.$domain.'): Code('._cozaepp_message($coderes).") $msg";
+			$values['error'] = 'RejectTransfer/domain-info('.$domain.'): Code('._zacr_message($coderes).") $msg";
 			return $values;
 		}
 
diff --git a/modules/registrars/cozaepp/cozaepppoll.php b/modules/registrars/zacr/zacrpoll.php
similarity index 93%
rename from modules/registrars/cozaepp/cozaepppoll.php
rename to modules/registrars/zacr/zacrpoll.php
index 498b5aeb29e1e4e0154cdb828bb43c16d085f1ba..33a22c7c3086f7974dc5eee7b0637508ecb6be89 100644
--- a/modules/registrars/cozaepp/cozaepppoll.php
+++ b/modules/registrars/zacr/zacrpoll.php
@@ -40,10 +40,10 @@
 # This file brings in a few constants we need
 require_once dirname(__FILE__) . '/../../../dbconnect.php';
 # Setup include dir
-$include_path = ROOTDIR . '/modules/registrars/cozaepp';
+$include_path = ROOTDIR . '/modules/registrars/zacr';
 set_include_path($include_path . PATH_SEPARATOR . get_include_path());
 # Include EPP stuff we need
-require_once 'cozaepp.php';
+require_once 'zacr.php';
 # Additional functions we need
 require_once ROOTDIR . '/includes/functions.php';
 # Include registrar functions aswell
@@ -54,14 +54,14 @@ require_once 'Net/EPP/Frame/Command.php';
 require_once 'Net/EPP/ObjectSpec.php';
 
 # Grab module parameters
-$params = getregistrarconfigoptions('cozaepp');
+$params = getregistrarconfigoptions('zacr');
 
-echo("COZA-EPP Poll Report\n");
+echo("ZACR Poll Report\n");
 echo("---------------------------------------------------\n");
 
 # Request balance from registrar
 try {
-	$client = _cozaepp_Client();
+	$client = _zacr_Client();
 
 	# Loop with message queue
 	while (!$last) {
@@ -95,7 +95,7 @@ try {
 					if (!in_array(trim($msgs->item($m)->textContent), $ignored)) {
 						$message = mysql_real_escape_string(trim($msgs->item($m)->textContent));
 						$result = mysql_query("
-							INSERT INTO mod_awit_cozaepp_messages
+							INSERT INTO mod_awit_zacr_messages
 								(
 									created,
 									code,
@@ -123,7 +123,7 @@ try {
 			if ($msgq) {
 				$msgid = $doc->getElementsByTagName('msgQ')->item(0)->getAttribute('id');
 				try {
-					$res = _cozaepp_ackpoll($client,$msgid);
+					$res = _zacr_ackpoll($client,$msgid);
 				} catch (Exception $e) {
 					echo("ERROR: ".$e->getMessage()."\n");
 				}
diff --git a/contrib/cozaeppdisableautorenew.php b/contrib/zacrdisableautorenew.php
similarity index 90%
rename from contrib/cozaeppdisableautorenew.php
rename to contrib/zacrdisableautorenew.php
index 9f6fa6bd5084d23159228ab08bdd340aa77f0537..8f5c3d731c8d8a54244473ad425e3655e84dcbf1 100644
--- a/contrib/cozaeppdisableautorenew.php
+++ b/contrib/zacrdisableautorenew.php
@@ -36,8 +36,8 @@
  * integration, customizations and consulting all available from
  * http://allworldit.com
 
  * Buzybuy - cozaepp Disable Auto Renew
  * This script is a modification of the original cozaeppsync.php script from AllWorldIT combined with code from
  * Everything Web CC script.
  * This script will loop through all the coza domains in your WHMCS database.
  * Each domain's auto renew will be set to false on the domain.
@@ -48,24 +48,24 @@
 // This file brings in a few constants we need
 require_once dirname(__FILE__) . '/../../../dbconnect.php';
 // Setup include dir
-$include_path = ROOTDIR . '/modules/registrars/cozaepp';
+$include_path = ROOTDIR . '/modules/registrars/zacr';
 set_include_path($include_path . PATH_SEPARATOR . get_include_path());
 // Include EPP stuff we need
-require_once 'cozaepp.php';
+require_once 'zacr.php';
 // Additional functions we need
 require_once ROOTDIR . '/includes/functions.php';
 // Include registrar functions aswell
 require_once ROOTDIR . '/includes/registrarfunctions.php';
 
 // Grab module parameters
-$params = getregistrarconfigoptions('cozaepp');
+$params = getregistrarconfigoptions('zacr');
 
-echo("COZA-EPP Domain Set Auto Renew To False Report\n");
+echo("ZACR Domain Set Auto Renew To False Report\n");
 echo("---------------------------------------------------\n");
 
 // Request balance from registrar
 try {
-	$client = _cozaepp_Client();
+	$client = _zacr_Client();
 
 	// Pull list of domains which are registered using this module
 	$queryresult = mysql_query("
@@ -73,7 +73,7 @@ try {
 					domain
 				FROM
 					tbldomains
-				WHERE registrar = 'cozaepp'"
+				WHERE registrar = 'zacr'"
 			);
 	while($data = mysql_fetch_array($queryresult)) {
 		$domains[] = trim(strtolower($data['domain']));
@@ -149,7 +149,7 @@ foreach ($domains as $domain) {
 					}
 				}
 			} else {
-				echo "Domain renew status update on $domain not successful: "._cozaepp_message($coderes)."\n";
+				echo "Domain renew status update on $domain not successful: "._zacr_message($coderes)."\n";
 				continue;
 			}
 		} else {
@@ -157,7 +157,7 @@ foreach ($domains as $domain) {
 			continue;
 		}
 	} else {
-		echo "Domain info on $domain not successful: "._cozaepp_message($coderes)."\n";
+		echo "Domain info on $domain not successful: "._zacr_message($coderes)."\n";
 		continue;
 	}
 
@@ -36,8 +36,8 @@
  * http://allworldit.com
 
- * Buzybuy - cozaepp Disable Auto Renew
- * This script is a modification of the original cozaeppsync.php script from AllWorldIT combined with code from
+ * Buzybuy - zacr Disable Auto Renew
+ * This script is a modification of the original zacrsync.php script from AllWorldIT combined with code from
  * Everything Web CC script.
  * This script will loop through all the coza domains in your WHMCS database.
diff --git a/modules/addons/awit_cozaepp/awit_cozaepp.php b/modules/addons/awit_zacr/awit_zacr.php
similarity index 89%
rename from modules/addons/awit_cozaepp/awit_cozaepp.php
rename to modules/addons/awit_zacr/awit_zacr.php
index bf848e66738d5820ca9febea957139e105abdf40..54ba15cb864f44daba621bc2fba22ce8a96e2492 100644
--- a/modules/addons/awit_cozaepp/awit_cozaepp.php
+++ b/modules/addons/awit_zacr/awit_zacr.php
@@ -1,6 +1,6 @@
 <?php
 /**
  * AWIT COZAEPP - COZA EPP Module
  * Copyright (c) 2014, AllWorldIT
  *
  * This program is free software: you can redistribute it and/or modify
@@ -23,17 +23,17 @@ if (!defined("WHMCS"))
 	die("This file cannot be accessed directly");
 
 // Our global supported field list
-$AWIT_COZAEPP_SUPPORTED_FIELDS = array(
+$AWIT_ZACR_SUPPORTED_FIELDS = array(
 	"max_items"
 );
 
 // Addon configuration
-function awit_cozaepp_config()
+function awit_zacr_config()
 {
 
 	// Configuration
 	$configarray = array(
-		"name" => "AWIT COZAEPP",
+		"name" => "AWIT ZACR",
 		"description" => "This module is to facilitate displaying of epp messages.",
 		"version" => "0.1",
 		"author" => "AllWorldIT",
@@ -54,21 +54,21 @@ function awit_cozaepp_config()
 
 
 
-function awit_cozaepp_get_config_custom_fields()
+function awit_zacr_get_config_custom_fields()
 {
-	global $AWIT_COZAEPP_SUPPORTED_FIELDS;
+	global $AWIT_ZACR_SUPPORTED_FIELDS;
 
 	// Query modules table
 	$table = "tbladdonmodules";
 	$fields = "setting,value";
-	$where = array( 'module' => 'awit_cozaepp' );
+	$where = array( 'module' => 'awit_zacr' );
 	$result = select_query($table,$fields,$where);
 
 	// Filter out the settings we need
 	$custom_fields = array();
 	while ($row = mysql_fetch_array($result)) {
 		// Check in our global list
-		if (in_array($row['setting'],$AWIT_COZAEPP_SUPPORTED_FIELDS)) {
+		if (in_array($row['setting'],$AWIT_ZACR_SUPPORTED_FIELDS)) {
 			$custom_fields[$row['setting']] = $row['value'];
 		}
 	}
@@ -78,21 +78,21 @@ function awit_cozaepp_get_config_custom_fields()
 
 
 
-function _awit_cozaepp_getMaxItems()
+function _awit_zacr_getMaxItems()
 {
-	$customFields = awit_cozaepp_get_config_custom_fields();
+	$customFields = awit_zacr_get_config_custom_fields();
 	return $customFields['max_items'];
 }
 
 
 
 // Addon activation
-function awit_cozaepp_activate()
+function awit_zacr_activate()
 {
 
 	// Create Custom DB Table
 	$result = mysql_query("
-		CREATE TABLE `mod_awit_cozaepp_messages` (
+		CREATE TABLE `mod_awit_zacr_messages` (
 			`id` INT( 1 ) NOT NULL AUTO_INCREMENT PRIMARY KEY,
 			`created` DATETIME NOT NULL,
 			`code` VARCHAR(10) NOT NULL,
@@ -111,11 +111,11 @@ function awit_cozaepp_activate()
 
 
 
-function awit_cozaepp_deactivate()
+function awit_zacr_deactivate()
 {
 	// Remove custom tables
 	$result1 = mysql_query("
-		DROP TABLE `mod_awit_cozaepp_messages`
+		DROP TABLE `mod_awit_zacr_messages`
 	");
 
 	if (!$result) {
@@ -129,7 +129,7 @@ function awit_cozaepp_deactivate()
 
 
 // Addon output
-function awit_cozaepp_output($vars)
+function awit_zacr_output($vars)
 {
 	// Check if we have to display all records
 	if (isset($_POST['button']) && $_POST['button'] == 'Display All') {
@@ -189,7 +189,7 @@ function awit_cozaepp_output($vars)
 	$orderClause = 'ORDER BY created DESC';
 
 	// Max amount of records to show per page
-	$recordMax = _awit_cozaepp_getMaxItems();
+	$recordMax = _awit_zacr_getMaxItems();
 
 	// Validation
 	if (!is_numeric($recordMax)) {
@@ -226,7 +226,7 @@ function awit_cozaepp_output($vars)
 			SELECT
 				COUNT(*) AS cnt
 			FROM
-				mod_awit_cozaepp_messages
+				mod_awit_zacr_messages
 			%s %s
 		",
 		$whereClause,
@@ -242,7 +242,7 @@ function awit_cozaepp_output($vars)
 			SELECT
 				*
 			FROM
-				mod_awit_cozaepp_messages
+				mod_awit_zacr_messages
 			%s %s %s
 		",
 		$whereClause,
@@ -1,6 +1,6 @@
 <?php
 /**
- * AWIT COZAEPP - COZA EPP Module
+ * AWIT ZACR - COZA EPP Module
  * Copyright (c) 2014, AllWorldIT
  *
diff --git a/modules/widgets/cozaepp_balance.php b/modules/widgets/zacr_balance.php
similarity index 79%
rename from modules/widgets/cozaepp_balance.php
rename to modules/widgets/zacr_balance.php
index 25d54d2ac791222768b856d1bcdcfbd1e18af0c7..b7b862de5357f2bf5bca4d227107202ae75180f1 100644
--- a/modules/widgets/cozaepp_balance.php
+++ b/modules/widgets/zacr_balance.php
@@ -1,16 +1,16 @@
 <?php
 # Copyright (c) 2012, AllWorldIT
-# 
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -18,49 +18,49 @@
 # Official Website:
 # http://devlabs.linuxassist.net/projects/whmcs-coza-epp
 
-# Lead developer: 
+# Lead developer:
 # Nigel Kukard <nkukard@lbsd.net>
 
 
 # ! ! P L E A S E   N O T E  ! !
 
-# * If you make changes to this file, please consider contributing 
+# * If you make changes to this file, please consider contributing
 #   anything useful back to the community. Don't be a sour prick.
 
-# * If you find this module useful please consider making a 
+# * If you find this module useful please consider making a
 #   donation to support modules like this.
 
 
-# WHMCS hosting, theming, module development, payment gateway 
-# integration, customizations and consulting all available from 
+# WHMCS hosting, theming, module development, payment gateway
+# integration, customizations and consulting all available from
 # http://allworldit.com
 
 
 
-# Function to implement the cozaepp balance widget
-function widget_cozaepp_balance($vars) {
+# Function to implement the zacr balance widget
+function widget_zacr_balance($vars) {
 	# Setup include dir
-	$include_path = ROOTDIR . '/modules/registrars/cozaepp';
+	$include_path = ROOTDIR . '/modules/registrars/zacr';
 	set_include_path($include_path . PATH_SEPARATOR . get_include_path());
 	# Include EPP stuff we need
-	require_once 'cozaepp.php';
+	require_once 'zacr.php';
 	# Include registrar functions aswell
 	require_once ROOTDIR . '/includes/registrarfunctions.php';
 
 
 	# Grab module parameters
-	$params = getregistrarconfigoptions('cozaepp');
+	$params = getregistrarconfigoptions('zacr');
 
 	# Set widget contents
-	$title = "COZA EPP Balance";
+	$title = "ZACR Balance";
 	$template = '<p align = "center" class="textblack"><strong>%s</strong></p>';
 
 	# Request balance from registrar
 	try {
-		$client = _cozaepp_Client();
+		$client = _zacr_Client();
 
 		$output = $client->request('
-<epp:epp xmlns:epp="urn:ietf:params:xml:ns:epp-1.0" xmlns:contact="urn:ietf:params:xml:ns:contact-1.0" 
+<epp:epp xmlns:epp="urn:ietf:params:xml:ns:epp-1.0" xmlns:contact="urn:ietf:params:xml:ns:contact-1.0"
 		xmlns:cozacontact="http://co.za/epp/extensions/cozacontact-1-0">
 	<epp:command>
 		<epp:info>
@@ -94,6 +94,6 @@ function widget_cozaepp_balance($vars) {
 	return array('title'=>$title,'content'=>sprintf($template,$balancestr));
 }
 
-add_hook("AdminHomeWidgets",1,"widget_cozaepp_balance");
+add_hook("AdminHomeWidgets",1,"widget_zacr_balance");
 
 ?>